<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package VideoStories
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comments">

	<?php
	// You can start editing here -- including this comment!
	if ( have_comments() ) { ?>
		<h2 class="section-title"><?php comments_number( esc_html('0 Comment' ,'videostories') , esc_html('1 Comment' ,'videostories'), esc_html('% Comments' ,'videostories') );?></h2>

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-above" class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'videostories' ); ?></h2>
			<div class="nav-links">

				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'videostories' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'videostories' ) ); ?></div>

			</div><!-- .nav-links -->
		</nav><!-- #comment-nav-above -->
		<?php endif; // Check for comment navigation. ?>

		<ol class="comment-list">
			<?php
                wp_list_comments( array(
                    'style'       => 'li',
                    'short_ping'  => true,
                    'callback' => 'videostories_comment',
                    'avatar_size' => 90
                ) );
                paginate_comments_links();
            ?>
		</ol><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) { // Are there comments to navigate through? ?>
			<nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
				<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'videostories' ); ?></h2>
				<div class="nav-links">

					<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'videostories' ) ); ?></div>
					<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'videostories' ) ); ?></div>

				</div><!-- .nav-links -->
			</nav><!-- #comment-nav-below -->
		<?php
		} // Check for comment navigation.

}


	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) { ?>

		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'videostories' ); ?></p>
	<?php
	} else{ ?>


			<div class="respond">
				<?php
					$commenter = wp_get_current_commenter();
					$req = get_option( 'require_name_email' );
					$aria_req = ( $req ? " aria-required='true'" : '' );
					$fields =  array(
						'author' => '<input id="author" class="form-control" name="author" type="text" placeholder="' . esc_html__('Name', 'videostories') . '" value="" size="30"' . $aria_req . '/>',
						'email'  => '<input id="email" class="form-control" name="email" type="email" placeholder="' . esc_html__('Email (required)', 'videostories') . '" value="" size="30"' . $aria_req . '/>',
						'url'  => '<input id="url" class="form-control" name="url" type="url" placeholder="' . esc_html__('Website', 'videostories') . '" value="">'
					);

					$comments_args = array(
						'fields' =>  $fields,
						'id_form'          			=> 'commentform',
						'title_reply'       		=> esc_html__( 'Leave a Comment', 'videostories' ),
						'title_reply_to'    		=> sprintf( 'Leave a Comment to %s'),
						'cancel_reply_link' 		=> esc_html__( 'Cancel Comment', 'videostories' ),
						'label_submit'      		=> esc_html__( 'Post Comment', 'videostories' ),
						'class_submit'      		=> 'btn',
						'comment_notes_before'      => '',
						'comment_notes_after' 		=> '',
						'id_submit'					=> 'submit',
						'comment_field'             => '<textarea id="comment" class="form-control" name="comment" placeholder="' . esc_html__('Comment*', 'videostories') . '" cols="40" rows="8" required></textarea>',
						'label_submit'              => esc_html__( 'Post Comment' , 'videostories' )
						);


					ob_start();
					comment_form( $comments_args);
				?>
			</div>


	<?php } ?>




</div><!-- #comments -->
